AU: Don't allow deltas if the rootfs track is different than the request track.

Currently such deltas are destined to fail because the rootfs hash will be
different than the expected hash.

BUG=9160
TEST=unit tests, tested on device

Change-Id: I588fcedb4a0ae16aca7197f771afab077d78fe05

Review URL: http://codereview.chromium.org/4988002
diff --git a/omaha_request_params.h b/omaha_request_params.h
index b8e2ee5..075ed3f 100644
--- a/omaha_request_params.h
+++ b/omaha_request_params.h
@@ -106,12 +106,13 @@
   bool IsValidTrack(const std::string& track) const;
 
   // Fetches the value for a given key from
   // /mnt/stateful_partition/etc/lsb-release if possible. Failing that, it looks
   // for the key in /etc/lsb-release. If |validator| is non-NULL, uses it to
   // validate and ignore invalid valies.
   std::string GetLsbValue(const std::string& key,
                           const std::string& default_value,
-                          ValueValidator validator) const;
+                          ValueValidator validator,
+                          bool stateful_override) const;
 
   // Gets the machine type (e.g. "i686").
   std::string GetMachineType() const;
@@ -106,12 +106,13 @@
 
   // Fetches the value for a given key from
-  // /mnt/stateful_partition/etc/lsb-release if possible. Failing that, it looks
-  // for the key in /etc/lsb-release. If |validator| is non-NULL, uses it to
-  // validate and ignore invalid valies.
+  // /mnt/stateful_partition/etc/lsb-release if possible and |stateful_override|
+  // is true. Failing that, it looks for the key in /etc/lsb-release. If
+  // |validator| is non-NULL, uses it to validate and ignore invalid valies.
   std::string GetLsbValue(const std::string& key,
                           const std::string& default_value,